package
Version:
v0.0.0-...-89505e1
Opens a new window with list of versions in this module.
Published: Oct 20, 2021
License: MIT
Opens a new window with license information.
Imports: 4
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type ParaLogin struct {
UserName string `form:"username" json:"username" xml:"username" binding:"required"`
Password string `form:"password" json:"password" xml:"password" binding:"required"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.